## START: Set by rpmautospec
## (rpmautospec version 0.6.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 3;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Building from fedora dependencies not possible
# Latest upstream rtnetlink frequently required
# sha2, zbus, zvariant are currently out of date

%global with_debug 1

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package %{nil}
%endif

# Minimum X.Y dep for aardvark-dns
%define major_minor %((v=%{version}; echo ${v%.*}))

# Set default firewall to nftables on CentOS Stream 10+, RHEL 10+
# and default to iptables on all other environments
# The `rhel` macro is defined on CentOS Stream, RHEL as well as Fedora ELN.
%if %{defined rhel} && 0%{?rhel} >= 10
%define default_fw nftables
%else
%define default_fw iptables
%endif

Name: netavark
# Set a different Epoch for copr builds
%if %{defined copr_username}
Epoch: 102
%else
Epoch: 2
%endif
Version: 1.11.0
Release: %autorelease
# The `AND` needs to be uppercase in the License for SPDX compatibility
License: Apache-2.0 AND BSD-3-Clause AND MIT
%if %{defined golang_arches_future}
ExclusiveArch: %{golang_arches_future}
%else
ExclusiveArch: aarch64 ppc64le s390x x86_64
%endif
Summary: OCI network stack
URL: https://github.com/containers/%{name}
# Tarballs fetched from upstream's release page
Source0: %{url}/archive/v%{version}.tar.gz
Source1: %{url}/releases/download/v%{version}/%{name}-v%{version}-vendor.tar.gz
BuildRequires: cargo
BuildRequires: %{_bindir}/go-md2man
# aardvark-dns and %%{name} are usually released in sync
Requires: aardvark-dns >=  %{epoch}:%{major_minor}
Provides: container-network-stack = 2
BuildRequires: make
BuildRequires: protobuf-c
BuildRequires: protobuf-compiler
%if %{defined rhel}
# rust-toolset requires the `local` repo enabled on non-koji ELN build environments
BuildRequires: rust-toolset
%else
BuildRequires: rust-packaging
BuildRequires: rust-srpm-macros
%endif
BuildRequires: git-core
BuildRequires: systemd
BuildRequires: systemd-devel

%description
%{summary}

Netavark is a rust based network stack for containers. It is being
designed to work with Podman but is also applicable for other OCI
container management applications.

Netavark is a tool for configuring networking for Linux containers.
Its features include:
* Configuration of container networks via JSON configuration file
* Creation and management of required network interfaces,
    including MACVLAN networks
* All required firewall configuration to perform NAT and port
    forwarding as required for containers
* Support for iptables and firewalld at present, with support
    for nftables planned in a future release
* Support for rootless containers
* Support for IPv4 and IPv6
* Support for container DNS resolution via aardvark-dns.

%prep
%autosetup -Sgit %{name}-%{version}
# Following steps are only required on environments like koji which have no
# network access and thus depend on the vendored tarball. Copr pulls
# dependencies directly from the network.
%if !%{defined copr_username}
tar fx %{SOURCE1}
mkdir -p .cargo

cat >.cargo/config << EOF
[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "vendor"
EOF
%endif

%build
NETAVARK_DEFAULT_FW=%{default_fw} %{__make} CARGO="%{__cargo}" build

cd docs
%{__make}

%install
%{__make} DESTDIR=%{buildroot} PREFIX=%{_prefix} install

%preun
%systemd_preun %{name}-dhcp-proxy.service
%systemd_preun %{name}-firewalld-reload.service

%postun
%systemd_postun %{name}-dhcp-proxy.service
%systemd_postun %{name}-firewalld-reload.service

%files
%license LICENSE
%dir %{_libexecdir}/podman
%{_libexecdir}/podman/%{name}*
%{_mandir}/man1/%{name}.1*
%{_unitdir}/%{name}-dhcp-proxy.service
%{_unitdir}/%{name}-dhcp-proxy.socket
%{_unitdir}/%{name}-firewalld-reload.service

%changelog
## START: Generated by rpmautospec
* Fri Jul 26 2024 Lokesh Mandvekar <lsm5@redhat.com> - 2:1.11.0-3
- rebuild

* Fri Jul 26 2024 Lokesh Mandvekar <lsm5@redhat.com> - 2:1.11.0-2
- rebuild

* Fri Jul 26 2024 Lokesh Mandvekar <lsm5@redhat.com> - 2:1.11.0-1
- epoch: 2 on non-copr

* Thu May 30 2024 Packit <hello@packit.dev> - 0:1.11.0-1
- Update to 1.11.0 upstream release

* Wed Mar 13 2024 Lokesh Mandvekar <lsm5@redhat.com> - 0:1.10.3-2
- make aardvark-dns a hard dep across the board

* Sat Feb 10 2024 Packit <hello@packit.dev> - 0:1.10.3-1
- [packit] 1.10.3 upstream release

* Wed Jan 31 2024 Packit <hello@packit.dev> - 0:1.10.2-1
- [packit] 1.10.2 upstream release

* Mon Jan 29 2024 Lokesh Mandvekar <lsm5@redhat.com> - 1.10.1-5
- remove min version on av

* Mon Jan 29 2024 Lokesh Mandvekar <lsm5@redhat.com> - 1.10.1-4
- remove commented lines

* Mon Jan 29 2024 Lokesh Mandvekar <lsm5@redhat.com> - 1.10.1-3
- depend on available version of av

* Mon Jan 29 2024 Adam Williamson <awilliam@redhat.com> - 1.10.1-2
- Fix broken dep on aardvark-dns 1.10.1 (does not exist)

* Thu Jan 25 2024 Packit <hello@packit.dev> - 1.10.1-1
- [packit] 1.10.1 upstream release

* Thu Jan 25 2024 Lokesh Mandvekar <lsm5@redhat.com> - 1.10.0-2
- fix cargo config

* Wed Jan 24 2024 Packit <hello@packit.dev> - 1.10.0-1
- [packit] 1.10.0 upstream release

* Mon Nov 27 2023 Packit <hello@packit.dev> - 1.9.0-1
- [packit] 1.9.0 upstream release

* Thu Sep 28 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.8.0-2
- update sources

* Wed Sep 27 2023 Packit <hello@packit.dev> - 1.8.0-1
- [packit] 1.8.0 upstream release

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jun 29 2023 Packit <hello@packit.dev> - 1.7.0-1
- [packit] 1.7.0 upstream release

* Tue May 30 2023 Yaakov Selkowitz <yselkowi@redhat.com> - 1.6.0-3
- Use rust-toolset in RHEL builds

* Wed Apr 12 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.6.0-2
- BR: systemd[-devel]

* Wed Apr 12 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.6.0-1
- bump to v1.6.0

* Tue Apr 11 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.5.0-7
- add dhcp-proxy unitfiles for upcoming v1.6

* Mon Mar 06 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.5.0-6
- exclusivearch: golang_arches_future

* Mon Mar 06 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.5.0-5
- migrated to SPDX license

* Wed Feb 08 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.5.0-4
- Resolves: #2167217 - enable debuginfo

* Wed Feb 08 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.5.0-3
- Discontinue i686

* Thu Feb 02 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.5.0-2
- rebuild for github 404 on koji

* Thu Feb 02 2023 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.5.0-1
- bump to v1.5.0

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Dec 12 2022 RH Container Bot <rhcontainerbot@fedoraproject.org> - 1.4.0-1
- auto bump to v1.4.0

* Wed Nov 23 2022 Yaakov Selkowitz <yselkowi@redhat.com> - 1.3.0-2
- Make md2man usage conditional on golang_arches

* Tue Nov 15 2022 RH Container Bot <rhcontainerbot@fedoraproject.org> - 1.3.0-1
- auto bump to v1.3.0

* Fri Oct 07 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.2.0-7
- Revert "auto bump to v1.2.0"

* Fri Oct 07 2022 RH Container Bot <rhcontainerbot@fedoraproject.org> - 1.2.0-6
- auto bump to v1.2.0

* Thu Oct 06 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.2.0-5
- make aardvark-dns hard requires on fedora-server

* Tue Oct 04 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.2.0-4
- adjust macros for correct version

* Tue Oct 04 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.2.0-3
- get rid of debbuild to comply with fedora guidelines

* Mon Oct 03 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.2.0-2
- bump lookaside cache files

* Wed Sep 28 2022 RH Container Bot <rhcontainerbot@fedoraproject.org> - 1.2.0-1
- auto bump to v1.2.0

* Wed Aug 17 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.1.0-3
- use easier tag macros to make both fedora and debbuild happy

* Tue Aug 16 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.1.0-2
- Fix debbuild maintainer issue

* Thu Jul 28 2022 RH Container Bot <rhcontainerbot@fedoraproject.org> - 1.1.0-1
- auto bump to v1.1.0

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri May 27 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.3-4
- build deb packages using debbuild

* Fri May 06 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.3-3
- add release tag info to aardvark dependency

* Fri May 06 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.3-2
- bump to v1.0.3

* Thu May 05 2022 RH Container Bot <rhcontainerbot@fedoraproject.org> - 1.0.3-1
- auto bump to v1.0.3

* Wed Mar 23 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.2-1
- bump to v1.0.2

* Fri Feb 25 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.1-1
- bump to v1.0.1, use upstream provided separate vendor tarball

* Wed Feb 16 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0-1
- bump to v1.0.0

* Fri Feb 11 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0~rc2-1
- bump to v1.0.0-rc2

* Thu Feb 10 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0~rc1-3
- aardvark-dns should be a weak-dep

* Wed Feb 02 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0~rc1-2
- Provides: container-network-stack = 2

* Tue Feb 01 2022 Lokesh Mandvekar <lsm5@fedoraproject.org> - 1.0.0~rc1-1
- Resolves: #2048794 - initial build
## END: Generated by rpmautospec
